# password_histories/apps.py
from django.apps import AppConfig


class PasswordHistoriesConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "password_histories"

    def ready(self):
        import password_histories.signals



# password_histories/signals.py
from django.contrib.auth import get_user_model
from django.dispatch import receiver
from django.db.models.signals import pre_save

from .models import PasswordHistory

User = get_user_model()


"""
Desc:
    Check if password is changed
    If password is changed, then store old password
"""
@receiver(pre_save, sender=User)
def save_password_history(sender, **kwargs):
    user = kwargs.get('instance', None)
    if user:
        new_password = user.password

        try:
            old_password = User.objects.get(pk=user.pk).password
        except User.DoesNotExist:
            old_password = None

        # when password is changed
        if new_password != old_password:

            # store old password
            if old_password:
                PasswordHistory.objects.create(
                    user=user,
                    password_hash=old_password
                )



# password_histories/models.py

from django.contrib.auth import get_user_model
from django.db import models


User = get_user_model()


class PasswordHistory(models.Model):
    user = models.ForeignKey(
        User,
        on_delete=models.CASCADE,
        related_name="user"
    )
    password_hash = models.CharField(
        max_length=250,
        blank=True,
        null=True,
        default=""
    )

    def __str__(self):
        if self.user.username:
            return "id: {}, user: {}".format(self.pk, self.user.username)
        else:
            return "id: {}".format(self.pk)
